==> haskell-vector-binary-instances-0.2.5.2-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-binary-instances
version:              0.2.5.2
visibility:           public
id:                   vector-binary-instances-0.2.5.2-9DGcPV8qi5H1mKDoAAqcln
key:                  vector-binary-instances-0.2.5.2-9DGcPV8qi5H1mKDoAAqcln
license:              BSD-3-Clause
maintainer:
    dons00@gmail.com, bos@serpentine.com, Ben Gamari <ben@smart-cactus.org>

author:               Don Stewart
stability:            Experimental
homepage:             https://github.com/bos/vector-binary-instances
synopsis:             Instances of Data.Binary for vector
description:
    Instances for Binary for the types defined in the vector package,
    making it easy to serialize vectors to and from disk. We use the
    generic interface to vectors, so all vector types are supported.
    Specific instances are provided for unboxed, boxed and storable
    vectors.
    .
    To serialize a vector:
    .
    > *Data.Vector.Binary> let v = Data.Vector.fromList [1..10]
    > *Data.Vector.Binary> v
    > fromList [1,2,3,4,5,6,7,8,9,10] :: Data.Vector.Vector
    > *Data.Vector.Binary> encode v
    > Chunk "\NUL\NUL\NUL\NUL\NUL...\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\n" Empty
    .
    Which you can in turn compress before writing to disk:
    .
    > compress . encode $ v
    > Chunk "\US\139\b\NUL\NUL\N...\229\240,\254:\NUL\NUL\NUL" Empty
    .
    Try the cereal-vector package if you are looking for Data.Serialize
    instances.

category:             Data
abi:                  f0b2f154672997a4d3f630e95f46aa9b
exposed:              True
exposed-modules:      Data.Vector.Binary
import-dirs:
    /usr/lib/ghc-9.0.1/site-local/vector-binary-instances-0.2.5.2

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/vector-binary-instances-0.2.5.2

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/vector-binary-instances-0.2.5.2

hs-libraries:         HSvector-binary-instances-0.2.5.2-9DGcPV8qi5H1mKDoAAqcln
depends:
    base-4.15.0.0 binary-0.8.8.0 vector-0.12.3.1-EtdN61cdG6Y4MwC0gVwGz6

haddock-interfaces:
    /usr/share/doc/haskell-vector-binary-instances/html/vector-binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-binary-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-binary-instances-0.2.5.2-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-binary-instances
version:              0.2.5.2
visibility:           public
id:                   vector-binary-instances-0.2.5.2-FEFRxy6fAui4rRCF8NL6u7
key:                  vector-binary-instances-0.2.5.2-FEFRxy6fAui4rRCF8NL6u7
license:              BSD-3-Clause
maintainer:
    dons00@gmail.com, bos@serpentine.com, Ben Gamari <ben@smart-cactus.org>

author:               Don Stewart
stability:            Experimental
homepage:             https://github.com/bos/vector-binary-instances
synopsis:             Instances of Data.Binary for vector
description:
    Instances for Binary for the types defined in the vector package,
    making it easy to serialize vectors to and from disk. We use the
    generic interface to vectors, so all vector types are supported.
    Specific instances are provided for unboxed, boxed and storable
    vectors.
    .
    To serialize a vector:
    .
    > *Data.Vector.Binary> let v = Data.Vector.fromList [1..10]
    > *Data.Vector.Binary> v
    > fromList [1,2,3,4,5,6,7,8,9,10] :: Data.Vector.Vector
    > *Data.Vector.Binary> encode v
    > Chunk "\NUL\NUL\NUL\NUL\NUL...\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\n" Empty
    .
    Which you can in turn compress before writing to disk:
    .
    > compress . encode $ v
    > Chunk "\US\139\b\NUL\NUL\N...\229\240,\254:\NUL\NUL\NUL" Empty
    .
    Try the cereal-vector package if you are looking for Data.Serialize
    instances.

category:             Data
abi:                  06601d681002bafd064e966f531d7ed3
exposed:              True
exposed-modules:      Data.Vector.Binary
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/vector-binary-instances-0.2.5.2

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/vector-binary-instances-0.2.5.2

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/vector-binary-instances-0.2.5.2

hs-libraries:         HSvector-binary-instances-0.2.5.2-FEFRxy6fAui4rRCF8NL6u7
depends:
    base-4.15.1.0 binary-0.8.8.0 vector-0.12.3.1-JI8sEYS2DW2BwfKSRTijMW

haddock-interfaces:
    /usr/share/doc/haskell-vector-binary-instances/html/vector-binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-binary-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
